openclean\_notebook.controller.spreadsheet package
==================================================

.. automodule:: openclean_notebook.controller.spreadsheet
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 3

   openclean_notebook.controller.spreadsheet.base
   openclean_notebook.controller.spreadsheet.data
